@@ -3,7 +3,7 @@ package X11::XCB::Event::Generic;
 use Mouse;
 
 # XXX: the following are filled in by XS
-has [ 'response_type', 'sequence' ] => (is => 'ro', isa => 'Int');
+has [ 'response_type', 'sequence', 'pad0' ] => (is => 'ro', isa => 'Int');
 
 __PACKAGE__->meta->make_immutable;
 
